==> larus_board-0.9.9.zip: larus_board-0.9.9/lb_private/lang/de/topic.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'add_bookmark'=>'Ein Lesezeichen anlegen',
'add_to_blacklist'=>'Autor auf die schwarze Liste setzen',
'back_to_search_results'=>'Zurück zu den Suchergebnissen',
'close_topic'=>'Thema schließen',
'delete_post'=>'Löschen',
'delete_report_posting_request'=>'Ich habe diesen Beitrag überprüft und entferne die "Meldung über gemeldeten Beitrag"...',
'deny_by_topic_acl'=>'Du hast keine Berechtigung dieses Thema zu lesen, weil du von der Zugriffsregel abgelehnt wurdest',
'edit_post'=>'Ändern',
'edit_profile'=>'Benutzerkonto ändern',
'link_to_this_posting'=>'Permanent-Link',
'moderation'=>'Moderation',
'open_topic'=>'Thema öffnen',
'other_topics_related_to_owner'=>'Der Themenstarter schrieb außerdem',
'other_topics_related_to_subject'=>'Diese Themen sind verwandt',
'posting_edited_by'=>'Geändert vom',
'posting_edited_reason'=>'Grund',
'posting_has_been_ignored'=>'Der Autor dieses Beitrages befindet sich auf deiner schwarzen Liste und daher kannst du die Nachricht nicht sehen.',
'posting_invisible'=>'Hinweis: Dieser Beitrag ist versteckt und nicht sichtbar für normale Benutzer.',
'posting_see_ignored_either'=>'Die Nachricht trotzdem anzeigen',
'post_new_reply'=>'Neue Antwort schreiben',
'post_quoted_reply'=>'Zitieren',
'purge_post_cache'=>'Beitrag-Zwischenspeicher löschen',
'purge_topic_cache'=>'Thema-Zwischenspeicher löschen',
'remove_bookmark'=>'Das Lesezeichen entfernen',
'remove_from_blacklist'=>'Autor von der schwarzen Liste nehmen',
'report_posting'=>'Beitrag melden',
'set_post_hidden'=>'Verstecken',
'set_post_visible'=>'Sichtbar',
'topic_view'=>'Themenansicht'
);
?>

==> larus_board-1.1.0.zip: larus_board-1.1.0/lb_private/lang/de/topic.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'add_bookmark'=>'Ein Lesezeichen anlegen',
'add_to_blacklist'=>'Autor auf die schwarze Liste setzen',
'back_to_search_results'=>'Zurück zu den Suchergebnissen',
'close_topic'=>'Thema schließen',
'delete_post'=>'Löschen',
'delete_report_posting_request'=>'Ich habe diesen Beitrag überprüft und entferne die "Meldung über gemeldeten Beitrag"...',
'deny_by_topic_acl'=>'Du hast keine Berechtigung dieses Thema zu lesen, weil du von der Zugriffsregel abgelehnt wurdest',
'edit_post'=>'Ändern',
'edit_profile'=>'Benutzerkonto ändern',
'link_to_this_posting'=>'Permanent-Link',
'moderation'=>'Moderation',
'open_topic'=>'Thema öffnen',
'other_topics_related_to_owner'=>'Der Themenstarter schrieb außerdem',
'other_topics_related_to_subject'=>'Diese Themen sind verwandt',
'posting_edited_by'=>'Geändert vom',
'posting_edited_reason'=>'Grund',
'posting_has_been_ignored'=>'Der Autor dieses Beitrages befindet sich auf deiner schwarzen Liste und daher kannst du die Nachricht nicht sehen.',
'posting_invisible'=>'Hinweis: Dieser Beitrag ist versteckt und nicht sichtbar für normale Benutzer.',
'posting_see_ignored_either'=>'Die Nachricht trotzdem anzeigen',
'post_new_reply'=>'Neue Antwort schreiben',
'post_quoted_reply'=>'Zitieren',
'purge_post_cache'=>'Beitrag-Zwischenspeicher löschen',
'purge_topic_cache'=>'Thema-Zwischenspeicher löschen',
'remove_bookmark'=>'Das Lesezeichen entfernen',
'remove_from_blacklist'=>'Autor von der schwarzen Liste nehmen',
'report_posting'=>'Beitrag melden',
'set_post_hidden'=>'Verstecken',
'set_post_visible'=>'Sichtbar',
'topic_is_pending_request'=>'Dieses Thema ist eine noch offene Anfrage. Ist sie abgeschlossen, solltest du das Thema schließen. Damit wird sie nicht mehr gelistet.',
'topic_view'=>'Themenansicht'
);
?>
